==> chaosmesh-model-6.5.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/StressChaosListFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface StressChaosListFluent<A extends StressChaosListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,StressChaos item);
  public A setToItems(Integer index,StressChaos item);
  public A addToItems(io.fabric8.chaosmesh.v1alpha1.StressChaos... items);
  public A addAllToItems(Collection<StressChaos> items);
  public A removeFromItems(io.fabric8.chaosmesh.v1alpha1.StressChaos... items);
  public A removeAllFromItems(Collection<StressChaos> items);
  public A removeMatchingFromItems(Predicate<StressChaosBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<StressChaos> getItems();
  public List<StressChaos> buildItems();
  public StressChaos buildItem(Integer index);
  public StressChaos buildFirstItem();
  public StressChaos buildLastItem();
  public StressChaos buildMatchingItem(Predicate<StressChaosBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<StressChaosBuilder> predicate);
  public A withItems(List<StressChaos> items);
  public A withItems(io.fabric8.chaosmesh.v1alpha1.StressChaos... items);
  public Boolean hasItems();
  public StressChaosListFluent.ItemsNested<A> addNewItem();
  public StressChaosListFluent.ItemsNested<A> addNewItemLike(StressChaos item);
  public StressChaosListFluent.ItemsNested<A> setNewItemLike(Integer index,StressChaos item);
  public StressChaosListFluent.ItemsNested<A> editItem(Integer index);
  public StressChaosListFluent.ItemsNested<A> editFirstItem();
  public StressChaosListFluent.ItemsNested<A> editLastItem();
  public StressChaosListFluent.ItemsNested<A> editMatchingItem(Predicate<StressChaosBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,StressChaosFluent<StressChaosListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/StressChaosListFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface StressChaosListFluent<A extends StressChaosListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,StressChaos item);
  public A setToItems(int index,StressChaos item);
  public A addToItems(io.fabric8.chaosmesh.v1alpha1.StressChaos... items);
  public A addAllToItems(Collection<StressChaos> items);
  public A removeFromItems(io.fabric8.chaosmesh.v1alpha1.StressChaos... items);
  public A removeAllFromItems(Collection<StressChaos> items);
  public A removeMatchingFromItems(Predicate<StressChaosBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<StressChaos> getItems();
  public List<StressChaos> buildItems();
  public StressChaos buildItem(int index);
  public StressChaos buildFirstItem();
  public StressChaos buildLastItem();
  public StressChaos buildMatchingItem(Predicate<StressChaosBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<StressChaosBuilder> predicate);
  public A withItems(List<StressChaos> items);
  public A withItems(io.fabric8.chaosmesh.v1alpha1.StressChaos... items);
  public Boolean hasItems();
  public StressChaosListFluent.ItemsNested<A> addNewItem();
  public StressChaosListFluent.ItemsNested<A> addNewItemLike(StressChaos item);
  public StressChaosListFluent.ItemsNested<A> setNewItemLike(int index,StressChaos item);
  public StressChaosListFluent.ItemsNested<A> editItem(int index);
  public StressChaosListFluent.ItemsNested<A> editFirstItem();
  public StressChaosListFluent.ItemsNested<A> editLastItem();
  public StressChaosListFluent.ItemsNested<A> editMatchingItem(Predicate<StressChaosBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,StressChaosFluent<StressChaosListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
